@@ -13,10 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
 from urllib import parse
 
 import fixtures
-import mock
 from oslotest import base as test_base
 import sqlalchemy
 from sqlalchemy.dialects import mysql
